@@ -32,19 +32,6 @@ TwitterTopBar::TwitterTopBar(QGraphicsWidget *parent)
         tweetsImage(QImage(":images/resources/topbar/tweets.png"))
 {
     this->setGeometry(0,0,800,57);
-//    QSettings settings("Zagaia","TweeGo");
-
-//    settings.beginGroup("PROXY");
-//    if(settings.value("useProxy").toBool()) {
-//        QNetworkProxy proxy;
-//        proxy.setType(QNetworkProxy::HttpProxy);
-//        proxy.setHostName(settings.value("ip").toString());
-//        proxy.setPort(settings.value("port").toInt());
-//        proxy.setUser(settings.value("user").toString());
-//        proxy.setPassword(settings.value("pass").toString());
-//        QNetworkProxy::setApplicationProxy(proxy);
-//    }
-//    settings.endGroup();
 
     font.setFamily("Nokia Sans");
     font.setStyle(QFont::StyleNormal);
@@ -78,7 +65,7 @@ TwitterTopBar::TwitterTopBar(QGraphicsWidget *parent)
     _buttonsList->addToList(_mentionsButton);
 
     // Get user's information from backend
-    user = Backend::getInstance()->userInfo();
+    user = getUserInformation();
 
     // Draw user's name
     _name = new QGraphicsTextItem(this);
@@ -112,8 +99,11 @@ TwitterTopBar::TwitterTopBar(QGraphicsWidget *parent)
     updateTopBar();
 
     setCacheMode(DeviceCoordinateCache);
-    connect(&m_manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(_handleNetworkRequest(QNetworkReply*)));
+
+    connect(&m_manager, SIGNAL(finished(QNetworkReply*)), SLOT(_handleNetworkRequest(QNetworkReply*)));
     connect(_refreshButton, SIGNAL(released()), SIGNAL(refresh()));
+    connect(_homeButton, SIGNAL(released()), SIGNAL(toHome()));
+    connect(_mentionsButton, SIGNAL(released()), SIGNAL(toMentions()));
 }
 
 /*!
@@ -122,11 +112,19 @@ TwitterTopBar::TwitterTopBar(QGraphicsWidget *parent)
 void TwitterTopBar::updateTopBar()
 {
     // Calculate position for tweets
+    user = getUserInformation();
     _positions();
 
     // Download user's avatar
     if(QString::compare(_imageUrl,user.imageUrl) || m_avatar == defaultAvatar )
         _download(user.imageUrl);
+
+    update();
+}
+
+UserInfo TwitterTopBar::getUserInformation(void)
+{
+    return Backend::getInstance()->userInfo();
 }
 
 /*!
