@@ -55,7 +55,6 @@ signals:
 
 private slots:
     void _postNewUpdate(void);
-    void _connectionError(QString);
     void _genericError(QString);
     void _handleFavorite(QString,bool);
     void _handleDeleteTweet(quint64);
@@ -63,13 +62,15 @@ private slots:
     void _handleFriendship(QString, bool);
     void _updateWarning(QString);
     void _refreshWarning(QString);
-    void _updateTimeline(void);
     void _updateProfileImage(QString);
     void _dialogLocation(void);
     void _handleGPSLocation(void);
-    void _populateTimeline(void);
-    void _refreshTimeline(void);
-    void _moreTweets(void);
+    void _populateHome(void);
+    void _populateMentions(void);
+    void _refreshHome(void);
+    void _moreHomeTweets(void);
+    void _refreshMentions(void);
+    void _moreMentions(void);
     void _updatePosted(void);
     void _deletedTweet(quint64);
 
