@@ -25,13 +25,13 @@
 /*!
  * \brief TimelineView constructor.
  */
-TimelineView::TimelineView(void)
+TimelineView::TimelineView(void) :
+        timelineOnScreen(NULL),
+        leftPos(-801,0),
+        centerPos(0,0),
+        rightPos(801,0)
 {
-//    qDebug() << "+ " << __PRETTY_FUNCTION__;
-
     _exitAnim = 0;
-//    _urlShortener = new UrlShortener;
-//    _ipLocation = new IpLocation;
 }
 
 /*!
@@ -54,8 +54,6 @@ void TimelineView::createUi(void)
 
     connect(qobject_cast<QObject *>(_exitAnim), SIGNAL(finished()), SIGNAL(done()));
 
-//    connect(_urlShortener, SIGNAL(newString(QString)), this, SLOT(_handleNewMessage(QString)));
-//    connect(_topBar, SIGNAL(changeAvatar(QString)), this, SLOT(_emitChangeAvatar(QString)));
 //    connect(_locationCheckBox, SIGNAL(pressed()), this, SIGNAL(showLocationDialog()));
 //    connect(_ipLocation, SIGNAL(finished(double, double)), this, SLOT(_showIpLocationInfo(double, double)));
 }
@@ -96,7 +94,7 @@ QAbstractAnimation *TimelineView::_createEntryAnimation(void)
  * \return anim Exit animation.
  * This method gets the entry animation and sets it backwards as the exit animation.
  */
-QAbstractAnimation *TimelineView::_createExitAnimation(void)
+QAbstractAnimation* TimelineView::_createExitAnimation(void)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
     QParallelAnimationGroup *anim = qobject_cast<QParallelAnimationGroup *>(_createEntryAnimation());
@@ -114,8 +112,19 @@ void TimelineView::_createTimeline()
     _homeTimeline->setPos(0,60);
     _homeTimeline->setZValue(1.0);
 
+    _mentionsTimeline = new KineticList(KineticList::Vertical, QSizeF(800,360), this);
+    _mentionsTimeline->setPos(801,60);
+    _mentionsTimeline->setZValue(1.0);
+
+    timelineOnScreen = _homeTimeline;
+
+    _timelines << _homeTimeline << _mentionsTimeline;
+    _downloadedTimelines << true << false;
+
     connect(_homeTimeline, SIGNAL(createTweetInfo(Tweet*)), SLOT(_createTweetInfo(Tweet*)));
-    connect(_homeTimeline, SIGNAL(moreTweets()),SIGNAL(moreTweets()));
+    connect(_homeTimeline, SIGNAL(moreTweets()),SLOT(_emitMoreTweets()));
+    connect(_mentionsTimeline, SIGNAL(moreTweets()), SLOT(_emitMoreTweets()));
+    connect(_mentionsTimeline, SIGNAL(createTweetInfo(Tweet*)), SLOT(_createTweetInfo(Tweet*)));
 }
 
 /*!
@@ -127,7 +136,9 @@ void TimelineView::_createTopBar()
     _topBar->setZValue(1.0);
 
     connect(_topBar, SIGNAL(settings()), _settingsDialog, SLOT(startAnimation()));
-    connect(_topBar, SIGNAL(refresh()), SIGNAL(refresh()));
+    connect(_topBar, SIGNAL(refresh()), SLOT(_emitRefresh()));
+    connect(_topBar, SIGNAL(toHome()), SLOT(_toHome()));
+    connect(_topBar, SIGNAL(toMentions()), SLOT(_toMentions()));
 }
 
 void TimelineView::_createSettings()
@@ -147,6 +158,7 @@ void TimelineView::_createButtons()
     _updateButton = new TwitterButton(TwitterButton::GenericDownRight,"Tweet",this);
     _updateButton->setOpacity(0);
     _updateButton->setZValue(3.0);
+    _updateButton->enable(false);
 
     _exposeButton = new TwitterButton(TwitterButton::Expose,"",this);
     _exposeButton->setOpacity(0);
@@ -165,7 +177,8 @@ void TimelineView::_createEntry()
     _entryUpdate->setPos(QPointF(100,435));
     _entryUpdate->setZValue(3.0);
 
-    connect(_entryUpdate, SIGNAL(enterPressed()), this, SLOT(_emitPostUpdate()));
+    connect(_entryUpdate, SIGNAL(enterPressed()), SLOT(_emitPostUpdate()));
+    connect(_entryUpdate, SIGNAL(textChanged(QString)), SLOT(_enableTweetButton(QString)));
 }
 
 /*!
@@ -186,6 +199,14 @@ void TimelineView::_createTweetInfo(Tweet *tweet)
 //    connect(this, SIGNAL(loadMap()), _tweetInfo, SLOT(_loadMap()));
 }
 
+void TimelineView::_enableTweetButton(QString msg)
+{
+    if(!msg.length() || msg.length() > 140)
+        _updateButton->enable(false);
+    else
+        _updateButton->enable(true);
+}
+
 /*!
  * \brief Adds opacity animation.
  * \param item the item that will be animated.
@@ -248,6 +269,88 @@ void TimelineView::_addPosAnim(QParallelAnimationGroup *anim,
     }
 }
 
+void TimelineView::_toHome(void)
+{
+    if(timelineOnScreen == _homeTimeline)
+        return;
+
+    KineticList *oldTimeline = timelineOnScreen;
+    timelineOnScreen = _homeTimeline;
+
+    _moveTimelines(oldTimeline,timelineOnScreen);
+}
+
+void TimelineView::_toMentions(void)
+{
+    if(timelineOnScreen == _mentionsTimeline)
+        return;
+
+    int pos = _timelines.indexOf(_mentionsTimeline);
+    if(!_downloadedTimelines.at(pos))
+    {
+        startLoader();
+        _downloadedTimelines.insert(pos,true);
+        emit getTimeline(Timeline::Mentions);
+    }
+
+    KineticList *oldTimeline = timelineOnScreen;
+    timelineOnScreen = _mentionsTimeline;
+
+    _moveTimelines(oldTimeline,timelineOnScreen);
+}
+
+void TimelineView::_moveTimelines(KineticList *oldTimeline, KineticList *newTimeline)
+{
+    int indexOld = _timelines.indexOf(oldTimeline);
+    int indexNew = _timelines.indexOf(newTimeline);
+
+    if(indexOld > indexNew) {
+        _moveToRight(oldTimeline,newTimeline);
+    } else {
+        _moveToLeft(oldTimeline,newTimeline);
+    }
+}
+
+void TimelineView::_moveToLeft(KineticList *oldTimeline, KineticList *newTimeline)
+{
+    QPropertyAnimation *anim1 = new QPropertyAnimation(oldTimeline,"pos");
+    anim1->setStartValue(oldTimeline->pos());
+    anim1->setEndValue(oldTimeline->pos() + leftPos);
+    anim1->setDuration(250);
+    anim1->setEasingCurve(QEasingCurve::Linear);
+
+    QPropertyAnimation *anim2 = new QPropertyAnimation(newTimeline,"pos");
+    anim2->setStartValue(newTimeline->pos());
+    anim2->setEndValue(newTimeline->pos() + leftPos);
+    anim2->setDuration(250);
+    anim2->setEasingCurve(QEasingCurve::Linear);
+
+    QParallelAnimationGroup *toleft = new QParallelAnimationGroup();
+    toleft->addAnimation(anim1);
+    toleft->addAnimation(anim2);
+    toleft->start();
+}
+
+void TimelineView::_moveToRight(KineticList *oldTimeline, KineticList *newTimeline)
+{
+    QPropertyAnimation *anim1 = new QPropertyAnimation(oldTimeline,"pos");
+    anim1->setStartValue(oldTimeline->pos());
+    anim1->setEndValue(oldTimeline->pos() + rightPos);
+    anim1->setDuration(250);
+    anim1->setEasingCurve(QEasingCurve::Linear);
+
+    QPropertyAnimation *anim2 = new QPropertyAnimation(newTimeline,"pos");
+    anim2->setStartValue(newTimeline->pos());
+    anim2->setEndValue(newTimeline->pos() + rightPos);
+    anim2->setDuration(250);
+    anim2->setEasingCurve(QEasingCurve::Linear);
+
+    QParallelAnimationGroup *toRight = new QParallelAnimationGroup();
+    toRight->addAnimation(anim1);
+    toRight->addAnimation(anim2);
+    toRight->start();
+}
+
 /*! \brief Gets the message typed on message edit box.
  *  \return message Message typed.
  */
@@ -266,6 +369,7 @@ void TimelineView::setUpdateMessage(const QString &message)
 
 void TimelineView::clearText(void)
 {
+    _updateButton->enable(true);
     _entryUpdate->clearText();
 }
 
@@ -275,17 +379,11 @@ void TimelineView::clearText(void)
  */
 void TimelineView::_emitPostUpdate()
 {
-//    if(_entryUpdate->getText().length() > 140) {
-//        if( this->containsUrl(getUpdateMessage()) > 0 ) {
-//            _urlShortener->parseUrl(getUpdateMessage());
-//            _updateButton->enable(false);
-//        }
-//    }
-//    else {
-    startLoader();
-    if(_entryUpdate->getText().length() < 141)
+    if(_entryUpdate->getText().length() < 141) {
+        startLoader();
+        _updateButton->enable(false);
         emit postUpdate();
-//    }
+    }
 }
 
 /*!
@@ -316,32 +414,6 @@ void TimelineView::_deleteLoader()
     _loader = NULL;
 }
 
-/*!
- * \brief This slot is called when there is any problem with the connection.
- * This slot starts the animation for the transition to the login screen.
- */
-void TimelineView::connectionError(void)
-{
-//    qDebug() << "+ " << __PRETTY_FUNCTION__;
-
-//    _loader->startExitAnimation();
-//    if (_exitAnim) {
-//        _exitAnim->start();
-//    } else {
-//        emit done();
-//    }
-}
-
-/*!
- * \brief Calls generic error on timelinectrl when an error while shortening the url occurs.
- * \param errorMessage Error message
- */
-void TimelineView::urlShorteningError(QString errorMessage)
-{
-//    qDebug() << "+ " << __PRETTY_FUNCTION__;
-//    emit shorteningError(errorMessage);
-}
-
 /*! \brief This slot is called to start loader's exit animation.
  */
 void TimelineView::endLoader()
@@ -355,31 +427,7 @@ void TimelineView::endLoader()
  */
 void TimelineView::updateTopBar(void)
 {
-//    qDebug() << "+ " << __PRETTY_FUNCTION__;
-
-//    _topBar->updateTopBar(false);
-//    _topBar->setPos(QPointF(800 - _logoutButton->boundingRect().width() - _topBar->boundingRect().width() -8, 0));
-}
-
-/*!
- * \brief Updates Parses the message checking if it has any url.
- * \param message message
- * \return cont Number of urls.
- */
-int TimelineView::containsUrl(QString message)
-{
-//    QList<QString> temp = message.split(" ");
-
-//        QListIterator<QString> iteratorUrl(temp);
-//    int cont = 0;
-//    while (iteratorUrl.hasNext()) {
-//        QString nextWord = iteratorUrl.next();
-
-//        if ( nextWord.contains( QRegExp("http://*") ) ){
-//            cont++;
-//        }
-//    }
-//    return cont;
+    _topBar->updateTopBar();
 }
 
 /*!
@@ -394,6 +442,26 @@ void TimelineView::_backToLogin()
     }
 }
 
+void TimelineView::_emitMoreTweets(void)
+{
+    startLoader();
+
+    if(timelineOnScreen == _homeTimeline)
+        emit moreHomeTweets();
+    else if(timelineOnScreen == _mentionsTimeline)
+        emit moreMentions();
+}
+
+void TimelineView::_emitRefresh(void)
+{
+    startLoader();
+
+    if(timelineOnScreen == _homeTimeline)
+        emit homeRefresh();
+    else if(timelineOnScreen == _mentionsTimeline)
+        emit mentionsRefresh();
+}
+
 /*!
  * \brief Emits an Unfollow signal.
  */
@@ -482,18 +550,6 @@ void TimelineView::setLocationCheckboxFalse()
 //    _locationCheckBox->setChecked(false);
 }
 
-void TimelineView::_moreButtonHome()
-{
-//    startLoader();
-//    emit moreButtonHome(m_homeTimeline);
-}
-
-void TimelineView::_moreButtonMentions()
-{
-//    startLoader();
-//    emit moreButtonMentions(m_mentionsTimeline);
-}
-
 /*!
  * \brief Sets the new message on the textbox after the user presses reply button.
  * \param newMessage message
@@ -551,9 +607,17 @@ bool TimelineView::getHome(void)
 //    return this->m_home;
 }
 
-void TimelineView::addMoreButton(void)
+void TimelineView::addMoreButton(Timeline::TimelineType type)
 {
-    _homeTimeline->addMoreButton();
+    switch(type)
+    {
+        case Timeline::Friends:
+            _homeTimeline->addMoreButton();
+            break;
+        case Timeline::Mentions:
+            _mentionsTimeline->addMoreButton();
+            break;
+    }
 }
 
 void TimelineView::tweetDeleted(quint64 id)
